@@ -33,7 +33,7 @@ license='MIT'
 
 """
 
-__version__ = "1.12.8"
+__version__ = "1.12.10"
 __repo__ = "https://github.com/adafruit/Adafruit_CircuitPython_Requests.git"
 
 import errno
@@ -50,7 +50,7 @@ if sys.implementation.name == "circuitpython":
 else:
     from ssl import SSLContext
     from types import ModuleType, TracebackType
-    from typing import Any, Dict, List, Optional, Tuple, Type, Union, cast
+    from typing import Any, Dict, Optional, Tuple, Type, Union, cast
 
     try:
         from typing import Protocol
@@ -64,15 +64,12 @@ else:
         def send(self, data: bytes, flags: int = ...) -> None:
             """Send data to the socket. The meaning of the optional flags kwarg is
             implementation-specific."""
-            ...
 
         def settimeout(self, value: Optional[float]) -> None:
             """Set a timeout on blocking socket operations."""
-            ...
 
         def close(self) -> None:
             """Close the socket."""
-            ...
 
     class CommonCircuitPythonSocketType(CommonSocketType, Protocol):
         """Describes the common structure every CircuitPython socket type must have."""
@@ -84,7 +81,6 @@ else:
         ) -> None:
             """Connect to a remote socket at the provided (host, port) address. The conntype
             kwarg optionally may indicate SSL or not, depending on the underlying interface."""
-            ...
 
     class LegacyCircuitPythonSocketType(CommonCircuitPythonSocketType, Protocol):
         """Describes the structure a legacy CircuitPython socket type must have."""
@@ -93,7 +89,6 @@ else:
             """Receive data from the socket. The return value is a bytes object representing
             the data received. The maximum amount of data to be received at once is specified
             by bufsize."""
-            ...
 
     class SupportsRecvWithFlags(Protocol):
         """Describes a type that posseses a socket recv() method supporting the flags kwarg."""
@@ -102,7 +97,6 @@ else:
             """Receive data from the socket. The return value is a bytes object representing
             the data received. The maximum amount of data to be received at once is specified
             by bufsize. The meaning of the optional flags kwarg is implementation-specific."""
-            ...
 
     class SupportsRecvInto(Protocol):
         """Describes a type that possesses a socket recv_into() method."""
@@ -114,7 +108,6 @@ else:
             buffer. If nbytes is not specified (or 0), receive up to the size available in the
             given buffer. The meaning of the optional flags kwarg is implementation-specific.
             Returns the number of bytes received."""
-            ...
 
     class CircuitPythonSocketType(
         CommonCircuitPythonSocketType,
@@ -124,8 +117,6 @@ else:
     ):  # pylint: disable=too-many-ancestors
         """Describes the structure every modern CircuitPython socket type must have."""
 
-        ...
-
     class StandardPythonSocketType(
         CommonSocketType, SupportsRecvInto, SupportsRecvWithFlags, Protocol
     ):
@@ -133,7 +124,6 @@ else:
 
         def connect(self, address: Union[Tuple[Any, ...], str, bytes]) -> None:
             """Connect to a remote socket at the provided address."""
-            ...
 
     SocketType = Union[
         LegacyCircuitPythonSocketType,
@@ -149,7 +139,6 @@ else:
         @property
         def TLS_MODE(self) -> int:  # pylint: disable=invalid-name
             """Constant representing that a socket's connection mode is TLS."""
-            ...
 
     SSLContextType = Union[SSLContext, "_FakeSSLContext"]
 
@@ -575,7 +564,7 @@ class Session:
         host: str,
         method: str,
         path: str,
-        headers: List[Dict[str, str]],
+        headers: Dict[str, str],
         data: Any,
         json: Any,
     ):
@@ -623,7 +612,7 @@ class Session:
         url: str,
         data: Optional[Any] = None,
         json: Optional[Any] = None,
-        headers: Optional[List[Dict[str, str]]] = None,
+        headers: Optional[Dict[str, str]] = None,
         stream: bool = False,
         timeout: float = 60,
     ) -> Response:
@@ -793,7 +782,7 @@ def request(
     url: str,
     data: Optional[Any] = None,
     json: Optional[Any] = None,
-    headers: Optional[List[Dict[str, str]]] = None,
+    headers: Optional[Dict[str, str]] = None,
     stream: bool = False,
     timeout: float = 1,
 ) -> None:
